@@ -6,7 +6,7 @@ use warnings;
 use Test::BDD::Cucumber::StepFile qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::HTTP::Util qw(C :util);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -46,6 +46,13 @@ Then qr/http response header "(.+)" must be like "(.+)"/, sub {
     header_re( $name, $value );
 };
 
+# Check http response header
+Then qr/http response header "(.+)" must be "(.+)"/, sub {
+    my ( $name, $value ) = ( $1, $2 );
+
+    header_eq( $name, $value );
+};
+
 # Check http response content
 Then qr/http response content must be "(.+)"/, sub {
     my ($value) = ($1);
@@ -60,4 +67,16 @@ Then qr/http response content must be like "(.+)"/, sub {
     content_re($value);
 };
 
+Then qr/http response decoded content must be "(.+)"/, sub {
+    my ($value) = ($1);
+
+    content_eq_decoded($value);
+};
+
+Then qr/http response decoded content must be like "(.+)"/, sub {
+    my ($value) = ($1);
+
+    content_re_decoded($value);
+};
+
 1;
