@@ -6,6 +6,8 @@ use warnings;
 use Carp;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
+use Hash::MultiValue;
+use HTTP::Response;
 use HTTP::Tiny;
 use Moose::Util::TypeConstraints;
 use Params::ValidationCompiler qw( validation_for );
@@ -13,10 +15,25 @@ use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-our @EXPORT_OK = qw(S C request_send code_eq header_re header_set content_eq content_re content_set);
-our %EXPORT_TAGS = ( util => [qw(request_send code_eq header_re header_set content_eq content_re content_set)] );
+our @EXPORT_OK = qw(
+    S C
+    request_send
+    code_eq
+    header_set header_eq header_re
+    content_set content_eq content_re content_eq_decoded content_re_decoded
+);
+our %EXPORT_TAGS = (
+    util => [
+        qw(
+            request_send
+            code_eq
+            header_set header_eq header_re
+            content_set content_eq content_re content_eq_decoded content_re_decoded
+            )
+    ]
+);
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
@@ -31,14 +48,14 @@ my $validator_header_set = validation_for(
         # http request header name
         {   type => subtype(
                 as 'Str',
-                message {qq{"$_" is not a valid http request header name}}
+                message {qq{"$_" is not a valid string}}
             ),
         },
 
         # http request header value
         {   type => subtype(
                 as 'Str',
-                message {qq{"$_" is not a valid http request header value}}
+                message {qq{"$_" is not a valid string}}
             ),
         }
     ]
@@ -58,7 +75,7 @@ my $validator_content_set = validation_for(
         # http request content
         {   type => subtype(
                 as 'Str',
-                message {qq{"$_" is not a valid http request content}}
+                message {qq{"$_" is not a valid string}}
             ),
         }
     ]
@@ -81,7 +98,7 @@ my $validator_request_send = validation_for(
         # http request url
         {   type => subtype(
                 as 'Str',
-                message {qq{"$_" is not a valid http request url}}
+                message {qq{"$_" is not a valid string}}
             ),
         }
     ]
@@ -116,6 +133,13 @@ sub request_send {
     # Clean http request
     S->{http}->{request} = undef;
 
+    S->{http}->{response_object} = HTTP::Response->new(
+        S->{http}->{response}->{status},
+        S->{http}->{response}->{reason},
+        [ Hash::MultiValue->from_mixed( S->{http}->{response}->{headers} )->flatten ],
+        S->{http}->{response}->{content},
+    );
+
     return;
 }
 
@@ -125,7 +149,7 @@ my $validator_code_eq = validation_for(
         # http response code
         {   type => subtype(
                 as 'Int',
-                message {qq{"$_" is not a valid http response code}}
+                message {qq{"$_" is not a valid integer}}
             ),
         }
     ]
@@ -142,6 +166,36 @@ sub code_eq {
     return;
 }
 
+my $validator_header_eq = validation_for(
+    params => [
+
+        # http response header name
+        {   type => subtype(
+                as 'Str',
+                message {qq{"$_" is not a valid http response header name}}
+            ),
+        },
+
+        # http response header value
+        {   type => subtype(
+                as 'Str',
+                message {qq{"$_" is not a valid string}}
+            ),
+        }
+
+    ]
+);
+
+sub header_eq {
+    my ( $header, $value ) = $validator_header_eq->(@_);
+
+    is( S->{http}->{response}->{headers}->{ lc $header }, $value, qq{Http response header "$header" eq "$value"} );
+
+    diag( 'Http response headers = ' . np S->{http}->{response}->{headers} );
+
+    return;
+}
+
 my $validator_header_re = validation_for(
     params => [
 
@@ -182,7 +236,7 @@ my $validator_content_eq = validation_for(
         # http response content
         {   type => subtype(
                 as 'Str',
-                message {qq{"$_" is not a valid http response content}}
+                message {qq{"$_" is not a valid string}}
             ),
         }
     ]
@@ -196,6 +250,17 @@ sub content_eq {
     return;
 }
 
+sub content_eq_decoded {
+    my ($content) = $validator_content_eq->(@_);
+
+    is( S->{http}->{response_object}->decoded_content(), $content, qq{Http response decoded content eq "$content"} );
+
+    diag( 'Http response content type = ' . np S->{http}->{response_object}->headers->content_type );
+    diag( 'Http response content charset = ' . np S->{http}->{response_object}->headers->content_type_charset );
+
+    return;
+}
+
 my $validator_content_re = validation_for(
     params => [
 
@@ -220,4 +285,19 @@ sub content_re {
     return;
 }
 
+sub content_re_decoded {
+    my ($content) = $validator_content_re->(@_);
+
+    like(
+        S->{http}->{response_object}->decoded_content(),
+        qr/$content/,    ## no critic [RegularExpressions::RequireExtendedFormatting]
+        qq{Http response decoded content re "$content"}
+    );
+
+    diag( 'Http response content type = ' . np S->{http}->{response_object}->headers->content_type );
+    diag( 'Http response content charset = ' . np S->{http}->{response_object}->headers->content_type_charset );
+
+    return;
+}
+
 1;
